# Define the disk to partition
DISK="/dev/sda"

# Create a new partition table
parted $DISK -- mklabel gpt

# Create a 512MB partition for UEFI boot
parted $DISK -- mkpart ESP fat32 1MiB 513MiB
parted $DISK -- set 1 boot on

# Create the root partition
parted $DISK -- mkpart primary ext4 513MiB 100%

# Format the boot partition
mkfs.fat -F32 ${DISK}1

# DO NOT FORMAT the root partition before encryption!
# cryptsetup will fail if the partition is already formatted

# Encrypt the root partition
cryptsetup luksFormat ${DISK}2
cryptsetup open ${DISK}2 root

# Now format the encrypted partition
mkfs.ext4 /dev/mapper/root

# Mount the partitions
mount /dev/mapper/root /mnt

mkdir -p /mnt/boot
mount ${DISK}1 /mnt/boot

# Clone the configuration repository
mkdir -p /mnt/etc/nixos
git clone https://git.luke-else.co.uk/luke-else/nixos-config.git /mnt/etc/nixos

# Generate NixOS configuration (optional if using flakes)
nixos-generate-config --root /mnt

# Install NixOS using the cloned configuration
nixos-install --flake /mnt/etc/nixos#vm

# Reboot the system
echo "Installation complete. Rebooting..."
reboot